---
# generated by https://github.com/hashicorp/terraform-plugin-docs
page_title: "vercel_dns_record Resource - terraform-provider-vercel"
subcategory: ""
description: |-
  Provides a DNS Record resource.
  DNS records are instructions that live in authoritative DNS servers and provide information about a domain.
  For more detailed information, please see the Vercel documentation https://vercel.com/docs/concepts/projects/custom-domains#dns-records
---

# vercel_dns_record (Resource)

Provides a DNS Record resource.

DNS records are instructions that live in authoritative DNS servers and provide information about a domain.

For more detailed information, please see the [Vercel documentation](https://vercel.com/docs/concepts/projects/custom-domains#dns-records)

## Example Usage

```terraform
resource "vercel_dns_record" "a" {
  domain = "example.com"
  name   = "subdomain" # for subdomain.example.com
  type   = "A"
  ttl    = 60
  value  = "192.168.0.1"
}

resource "vercel_dns_record" "aaaa" {
  domain = "example.com"
  name   = "subdomain"
  type   = "AAAA"
  ttl    = 60
  value  = "::0"
}

resource "vercel_dns_record" "alias" {
  domain = "example.com"
  name   = "subdomain"
  type   = "ALIAS"
  ttl    = 60
  value  = "example2.com."
}

resource "vercel_dns_record" "caa" {
  domain = "example.com"
  name   = "subdomain"
  type   = "CAA"
  ttl    = 60
  value  = "1 issue \"letsencrypt.org\""
}

resource "vercel_dns_record" "cname" {
  domain = "example.com"
  name   = "subdomain"
  type   = "CNAME"
  ttl    = 60
  value  = "example2.com."
}

resource "vercel_dns_record" "mx" {
  domain      = "example.com"
  name        = "subdomain"
  type        = "MX"
  ttl         = 60
  mx_priority = 333
  value       = "example2.com."
}

resource "vercel_dns_record" "srv" {
  domain = "example.com"
  name   = "subdomain"
  type   = "SRV"
  ttl    = 60
  srv = {
    port     = 6000
    weight   = 60
    priority = 127
    target   = "example2.com."
  }
}

resource "vercel_dns_record" "txt" {
  domain = "example.com"
  name   = "subdomain"
  type   = "TXT"
  ttl    = 60
  value  = "some text value"
}
```

<!-- schema generated by tfplugindocs -->
## Schema

### Required

- `domain` (String) The domain name, or zone, that the DNS record should be created beneath.
- `name` (String) The subdomain name of the record. This should be an empty string if the rercord is for the root domain.
- `type` (String) The type of DNS record.

### Optional

- `mx_priority` (Number) The priority of the MX record. The priority specifies the sequence that an email server receives emails. A smaller value indicates a higher priority.
- `srv` (Attributes) Settings for an SRV record. (see [below for nested schema](#nestedatt--srv))
- `team_id` (String) The team ID that the domain and DNS records belong to.
- `ttl` (Number) The TTL value in seconds. Must be a number between 60 and 2147483647. If unspecified, it will default to 60 seconds.
- `value` (String) The value of the DNS record. The format depends on the 'type' property.
For an 'A' record, this should be a valid IPv4 address.
For an 'AAAA' record, this should be an IPv6 address.
For 'ALIAS' records, this should be a hostname.
For 'CAA' records, this should specify specify which Certificate Authorities (CAs) are allowed to issue certificates for the domain.
For 'CNAME' records, this should be a different domain name.
For 'MX' records, this should specify the mail server responsible for accepting messages on behalf of the domain name.
For 'TXT' records, this can contain arbitrary text.

### Read-Only

- `id` (String) The ID of this resource.

<a id="nestedatt--srv"></a>
### Nested Schema for `srv`

Optional:

- `port` (Number) The TCP or UDP port on which the service is to be found.
- `priority` (Number) The priority of the target host, lower value means more preferred.
- `target` (String) The canonical hostname of the machine providing the service, ending in a dot.
- `weight` (Number) A relative weight for records with the same priority, higher value means higher chance of getting picked.

## Import

Import is supported using the following syntax:

```shell
# Import via the team_id and record ID.
# Record ID can be taken from the network tab on the domains page.
terraform import vercel_dns_record.example team_xxxxxxxxxxxxxxxxxxxxxxxx/rec_xxxxxxxxxxxxxxxxxxxxxxxxxxxx

# If importing without a team, simply use the record ID.
terraform import vercel_dns_record.personal_example rec_xxxxxxxxxxxxxxxxxxxxxxxxxxxx
```
